# ttkwidgets
[![Build Status](https://travis-ci.org/RedFantom/ttkwidgets.svg?branch=master)](https://travis-ci.org/RedFantom/ttkwidgets)
[![Build status](https://ci.appveyor.com/api/projects/status/c6j6td273u3y6rw7/branch/master?svg=true)](https://ci.appveyor.com/project/RedFantom/ttkwidgets/branch/master)
[![codecov](https://codecov.io/gh/RedFantom/ttkwidgets/branch/master/graph/badge.svg)](https://codecov.io/gh/RedFantom/ttkwidgets)
[![PyPI version](https://badge.fury.io/py/ttkwidgets.svg)](https://badge.fury.io/py/ttkwidgets)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![Documentation Status](https://readthedocs.org/projects/ttkwidgets/badge/?version=latest)](https://ttkwidgets.readthedocs.io/en/latest/)

A collection of widgets for Tkinter's ttk extensions by various authors.

## License
    ttkwidgets: A collection of widgets for Tkinter's ttk extensions by various authors 
    Copyright (C) RedFantom 2017
    Copyright (C) The Python Team
    Copyright (C) Mitja Martini 2008
    Copyright (C) Russell Adams 2011
    Copyright (C) Juliette Monsel 2017
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

## Installation
- With pip:

        pip install ttkwidgets

- Ubuntu: ttkwidgets is available in the PPA [ppa:j-4321-i/ttkwidgets](https://launchpad.net/~j-4321-i/+archive/ubuntu/ttkwidgets).

        sudo add-apt-repository ppa:j-4321-i/ttkwidgets
        sudo apt-get update
        sudo apt-get install python(3)-ttkwidgets

- Archlinux: ttkwidgets is available in [AUR](https://aur.archlinux.org/packages/python-ttkwidgets).

## Documentation
Online documentation is available here: https://ttkwidgets.readthedocs.io/en/latest/

## Contributing
If you have created a widget that you think is worth adding, then feel free to fork the repository and create a Pull
Request when you've added the widget to your copy of the repository. You will be credited for your work, and you can add
headers to your files. You will also be added to the [AUTHORS.md](AUTHORS.md) file.

## Issues
If you find any bugs or have any ideas, feel free to open an issue here in the repository, and it will be looked at.

